@@ -1,4 +1,6 @@
 nodeDist<-function(trees,sp1,sp2,relTime=F,fillcol="blue",xlabel="Age (mya)",main="",return.ages=F,plot=T,add=F,...){
+tree<-trees
+if (is(trees,"phylo")) trees<-c(trees,trees)
 ages<-c()
 for (i in 1:length(trees)){
 time.from.root<-findMRCA(trees[[i]],tips=c(sp1,sp2),type="height")
@@ -14,6 +16,10 @@ lines(agedist)
 print("As you are adding a distribution to an existing plot, make sure xlim and ylim on original plot are set to accomodate all plotted distributions")
 }
 polygon(agedist,col=fillcol)
+if (is(trees,"phylo")) warning("This distribution is based on a single age estimate as only one tree (not a set) was provided")
+}
+if (return.ages==T) {
+if (is(tree,"phylo")) ages[1]
+else ages
+}
 }
-if (return.ages==T) ages
-}
\ No newline at end of file
